open Printf
open Globals

let default_numthreads = 8
let default_numruns    = 1000
let gen_makefile arch = 
  let logdir     = "LOGDIR        ?= logs\n" in
  let numthreads = sprintf "NUMTHREADS    ?= %i\n" default_numthreads in 
  let numruns    = sprintf "NUMRUNS       ?= %i\n" default_numruns in
  match get_target_os arch with
  |  Linux -> 
      let cpuinfo    = "\tcat /proc/cpuinfo > $(LOGDIR)/log_cpuinfo\n" in
      logdir ^
      numthreads ^
      numruns ^
      "\nall:\n" ^
      "\tmkdir -p $(LOGDIR)\n" ^
      "\t(cd src ; sh comp.sh)\n" ^
      "\ttime (cd src; sh run.sh -a $(NUMTHREADS) -r $(NUMRUNS) \\\n" ^
      "            > ../$(LOGDIR)/log_out 2> ../$(LOGDIR)/log_err ) \\\n" ^
      "            2> $(LOGDIR)/log_time\n" ^ 
      cpuinfo 
  | AIX ->
      let cpuinfo    = "\techo 'CPUINFO unsupported for this OS' > $(LOGDIR)/log_cpuinfo\n" in
      logdir ^
      numthreads ^
      numruns ^
      "\nall:\n" ^
      "\tmkdir -p $(LOGDIR)\n" ^
      "\t(cd src ; sh comp.sh)\n" ^
      "\ttime (cd src; sh run.sh -a $(NUMTHREADS) -r $(NUMRUNS) \\\n" ^
      "            > ../$(LOGDIR)/log_out 2> ../$(LOGDIR)/log_err ) \\\n" ^
      "            2> $(LOGDIR)/log_time\n" ^
      cpuinfo
  | Mac -> "generateCrossDoc.ml does not support Mac" 



                   
